@@ -102,10 +102,10 @@ class SecurityDataClient(object):
                         - ``PERSONAL_CLOUD_SCAN_RESULT``
 
                     Defaults to None.
-            min_timestamp (float, optional): A POSIX timestamp representing the beginning of the
-                date range of events to get. Defaults to None.
-            max_timestamp (float, optional): A POSIX timestamp representing the end of the date
-                range of events to get. Defaults to None.
+            min_timestamp (int or float or str or datetime, optional): Timestamp in milliseconds or
+                str format "yyyy-MM-DD HH:MM:SS" or a datetime instance. Defaults to None.
+            max_timestamp (int or float or str or datetime, optional): Timestamp in milliseconds or
+                str format "yyyy-MM-DD HH:MM:SS" or a datetime instance. Defaults to None.
 
         Returns:
             generator: An object that iterates over :class:`py42.response.Py42Response` objects
@@ -152,10 +152,10 @@ class SecurityDataClient(object):
                         - ``PERSONAL_CLOUD_SCAN_RESULT``
 
                     Defaults to None.
-            min_timestamp (float, optional): A POSIX timestamp representing the beginning of the
-                date range of events to get. Defaults to None.
-            max_timestamp (float, optional): A POSIX timestamp representing the end of the date
-                range of events to get. Defaults to None.
+            min_timestamp (int or float or str or datetime, optional): Timestamp in milliseconds or
+                str format "yyyy-MM-DD HH:MM:SS" or a datetime instance. Defaults to None.
+            max_timestamp (int or float or str or datetime, optional): Timestamp in milliseconds or
+                str format "yyyy-MM-DD HH:MM:SS" or a datetime instance. Defaults to None.
 
         Returns:
             generator: An object that iterates over :class:`py42.response.Py42Response` objects
@@ -172,12 +172,12 @@ class SecurityDataClient(object):
         )
 
     def search_file_events(self, query):
-        """Searches for file events.
+        """Searches for file events, returns up to the first 10,000 events.
         `REST Documentation <https://support.code42.com/Administrator/Cloud/Monitoring_and_managing/Forensic_File_Search_API>`__
 
         Args:
-            query (:class:`py42.sdk.queries.fileevents.file_event_query.FileEventQuery`): Also
-                accepts a raw JSON str.
+            query (str or :class:`py42.sdk.queries.fileevents.file_event_query.FileEventQuery`):
+                The file event query to filter search results.
 
         Returns:
             :class:`py42.response.Py42Response`: A response containing the first 10,000
@@ -185,6 +185,28 @@ class SecurityDataClient(object):
         """
         return self._file_event_service.search(query)
 
+    def search_all_file_events(self, query, page_token=""):
+        """Searches for all file events, returning a page of events with a token in the response to retrieve next page.
+
+        `REST Documentation <https://support.code42.com/Administrator/Cloud/Monitoring_and_managing/Forensic_File_Search_API>`__
+
+        Args:
+            query (str or :class:`py42.sdk.queries.fileevents.file_event_query.FileEventQuery`):
+                The file event query to filter search results.
+            page_token (str, optional): A token used to indicate the starting point for
+                additional page results. For the first page, do not pass ``page_token``. For
+                all consecutive pages, pass the token from the previous response from
+                field ``nextPgToken``. When using ``page_token``, any sorting parameters from
+                the `FileEventQuery` will be ignored. Defaults to empty string.
+
+        Returns:
+            :class:`py42.response.Py42Response`: A response containing page of events.
+        """
+
+        query.page_token = page_token
+        response = self._file_event_service.search(query)
+        return response
+
     def stream_file_by_sha256(self, checksum):
         """Stream file based on SHA256 checksum.
 
