@@ -1,14 +1,15 @@
-from py42._internal.compat import str
+from py42._compat import str
 from py42.sdk.queries import BaseQuery
 
 
 class AlertQuery(BaseQuery):
     """Helper class for building Code42 Alert queries.
 
-    An AlertQuery instance's ``all()`` and ``any()`` take one or more :class:`FilterGroup`
-    objects to construct a query that can be passed to the :meth:`AlertClient.search()` method.
-    ``all()`` returns results that match all of the provided filter criteria, ``any()`` will return
-    results that match any of the filters.
+    An AlertQuery instance's ``all()`` and ``any()`` take one or more
+    :class:`~py42.sdk.queries.query_filter.FilterGroup` objects to construct a query that
+    can be passed to the :meth:`AlertService.search()` method. ``all()`` returns results
+    that match all of the provided filter criteria, ``any()`` will return results that
+    match any of the filters.
 
     For convenience, the :class:`AlertQuery` constructor does the same as ``all()``.
 
@@ -52,4 +53,4 @@ class AlertQuery(BaseQuery):
             u"srtKey": self.sort_key,
         }
         for key in output_dict:
-            yield (key, output_dict[key])
+            yield key, output_dict[key]
