@@ -2,7 +2,9 @@ from py42._compat import str
 from py42.sdk.queries import BaseQuery
 from py42.sdk.queries.query_filter import create_filter_group
 from py42.sdk.queries.query_filter import create_query_filter
+from py42.sdk.queries.query_filter import create_within_the_last_filter_group
 from py42.sdk.queries.query_filter import QueryFilterStringField
+from py42.sdk.queries.query_filter import QueryFilterTimestampField
 
 
 class FileEventQuery(BaseQuery):
@@ -27,19 +29,20 @@ class FileEventQuery(BaseQuery):
     def __init__(self, *args, **kwargs):
         super(FileEventQuery, self).__init__(*args, **kwargs)
         self.sort_key = u"eventId"
-        self.page_number = 1
 
     def __str__(self):
         groups_string = u",".join(
             str(group_item) for group_item in self._filter_group_list
         )
-        json = u'{{"groupClause":"{0}", "groups":[{1}], "pgNum":{2}, "pgSize":{3}, "srtDir":"{4}", "srtKey":"{5}"}}'.format(
-            self._group_clause,
-            groups_string,
-            self.page_number,
-            self.page_size,
-            self.sort_direction,
-            self.sort_key,
+        if self.page_token is not None:
+            paging_prop = u'"pgToken":"{}"'.format(self.page_token)
+
+        else:
+            paging_prop = u'"srtDir":"{}", "srtKey":"{}", "pgNum":{}'.format(
+                self.sort_direction, self.sort_key, self.page_number,
+            )
+        json = u'{{"groupClause":"{0}", "groups":[{1}], {2}, "pgSize":{3}}}'.format(
+            self._group_clause, groups_string, paging_prop, self.page_size
         )
         return json
 
@@ -52,6 +55,7 @@ class FileEventQuery(BaseQuery):
             u"pgSize": self.page_size,
             u"srtDir": self.sort_direction,
             u"srtKey": self.sort_key,
+            u"pgToken": self.page_token,
         }
         for key in output_dict:
             yield key, output_dict[key]
@@ -177,3 +181,20 @@ class FileEventFilterComparableField(object):
         """
         value = int(value)
         return create_less_than_filter_group(cls._term, value)
+
+
+class FileEventFilterTimestampField(QueryFilterTimestampField):
+    @classmethod
+    def within_the_last(cls, value):
+        """Returns a :class:`~py42.sdk.queries.query_filter.FilterGroup` that is useful
+        for finding results where the key ``self._term`` is a timestamp-related term,
+        such as ``EventTimestamp._term``, and ``value`` is one of it's accepted values,
+        such as one of the values in ``EventTimestamp.choices()``.
+
+        Args:
+            value (str): The value used to filter file events.
+
+        Returns:
+            :class:`~py42.sdk.queries.query_filter.FilterGroup`
+        """
+        return create_within_the_last_filter_group(cls._term, value)
